<?php namespace Drupal\cmrf_views\Plugin\views\field;

use DateTime;
use Drupal\views\ResultRow;

/**
 * Class File
 *
 * @package Drupal\cmrf_views\Plugin\views\field
 * @ingroup cmrf_views_field_handlers
 * @ViewsField("cmrf_views_date")
 */
class Date extends \Drupal\views\Plugin\views\field\Date {

  /**
   * {@inheritdoc}
   */
  public function getValue(ResultRow $values, $field = NULL) {
    $alias = isset($field) ? $this->aliases[$field] : $this->field_alias;
    if (!empty($values->{$alias})) {
      try {
        $date_time = new DateTime($values->{$alias});
        return $date_time->format('U');
      } catch (\Exception $e) {
        // if a data cannot be converted it is often because the dataformat
        // on the api that is called is not correctly set. 'Y-m-d' is
        // a good choice.
        return 'N/A';
      }
    }
    return NULL;
  }

  /**
   * @param \Drupal\views\ResultRow $values
   *
   * @return \Drupal\Component\Render\MarkupInterface|\Drupal\Core\Datetime\FormattedDateDiff|\Drupal\Core\StringTranslation\TranslatableMarkup|\Drupal\views\Render\ViewsRenderPipelineMarkup|string|void
   */
  public function render(ResultRow $values) {
    $value = $this->getValue($values);
    // skip all the date functionality that is not
    // applicable to N/A
    if($value== 'N/A') {
      return $value;
    } else {
      return parent::render($values);
    }
  }

}
